import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {environment} from '../../../../environments/environment';
import {MerchantService} from '../../../services/merchant.service';
import {NzMessageService, NzUploadFile} from 'ng-zorro-antd';
import {ActivatedRoute} from '@angular/router';
import {CouponService} from '../../../services/coupon.service';
import {forEachToken} from 'tslint';
function getBase64(file: File): Promise<string | ArrayBuffer | null> {
  return new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.readAsDataURL(file);
    reader.onload = () => resolve(reader.result);
    reader.onerror = error => reject(error);
  });
}

@Component({
  selector: 'app-coupon-edit',
  templateUrl: './coupon-edit.component.html',
  styleUrls: ['./coupon-edit.component.scss']
})
export class CouponEditComponent implements OnInit {



  validateForm!: FormGroup;
  data: any;
  editFlag = false;
  id: number;
  couponImg = [];
  couponCarouselImg = [];
  WEB_SERVE_URL = environment.baseUrl;
  previewImage: string | undefined = '';
  previewVisible = false;
  optionList: string[] = [];
  isLoading = false;
  pageNum = 1;
  merchantName: string;
  optionListCoupon: string[] = [];
  isLoadingCoupon = false;
  pageNumCoupon = 1;
  couponName: string;
  content: string;
  constructor(
      private fb: FormBuilder,
      private merchant: MerchantService,
      private coupon: CouponService,
      private message: NzMessageService, // 信息提示
      private activatedRoute: ActivatedRoute,
  ) {
  }





  ngOnInit(): void {
    this.activatedRoute.queryParams.subscribe(queryParams => {
      if (queryParams.merchantId != null) {
        this.editFlag = true;
        this.id = queryParams.merchantId;
        this.getDetails(queryParams.merchantId);
      }
    });
    this.validateForm = this.fb.group({
      couponName: [null, [Validators.required]],
      couponPrice: [null, [Validators.required]],
      couponDesc: [null],
      couponType: [null, [Validators.required]],
      salesEndTime: [null, [Validators.required]],
      recycleDay: [1, [Validators.required]],
      limitNumber: [null, [Validators.required]],
      salesPrice: [null, [Validators.required]],
      salesCount: [null, [Validators.required]],
      merchantId: [null, [Validators.required]],
      isPresent: [false, [Validators.required]],
      handselCouponList: [null],
      status: [null],
      createTime: [null],
      secUser: {},
    });
  }


  // 查询商户
  loadMore(): void {
    this.isLoading = true;
    const paramsObject = {
      pageNum: this.pageNum,
      pageSize: 10,
      merchantName: this.merchantName,
    };
    this.getMerchantList(paramsObject);
  }

  // 搜索商户
  search(e): void {
    this.optionList = [];
    this.isLoading = true;
    this.merchantName = e;
    this.pageNum = 1;
    const paramsObject = {
      pageNum: this.pageNum,
      pageSize: 10,
      merchantName: e,
    };
    this.getMerchantList(paramsObject);
  }

  // 查询商户
  public getMerchantList(paramsObject): void {
    this.merchant.getMerchantList(paramsObject , data => {
      if (data['return_code'] === '000000' && this.pageNum <= data['return_data'].pages ) {
        this.pageNum ++;
        this.isLoading = false;
        this.optionList = [...this.optionList, ...data['return_data'].list];
      } else {
        this.isLoading = false;
      }
    });
  }

  // 查询卡券
  loadMoreCoupon(): void {
    this.isLoadingCoupon = true;
    const paramsObject = {
      pageNum: this.pageNumCoupon,
      pageSize: 10,
      merchantName: this.merchantName,
    };
    this.getCouponList(paramsObject);
  }

  // 搜索卡券
  searchCoupon(e): void {
    this.optionListCoupon = [];
    this.isLoadingCoupon = true;
    this.merchantName = e;
    this.pageNumCoupon = 1;
    const paramsObject = {
      pageNum: this.pageNumCoupon,
      pageSize: 10,
      merchantName: e,
    };
    this.getCouponList(paramsObject);
  }

  // 查询卡券
  public getCouponList(paramsObject): void {
    this.coupon.getCouponList(paramsObject , data => {
      console.log(data);
      if (data['return_code'] === '000000' && this.pageNum <= data['return_data'].pages ) {
        this.pageNum ++;
        this.isLoading = false;
        this.optionList = [...this.optionList, ...data['return_data'].list];
      } else {
        this.isLoading = false;
      }
    });
  }

  // 返回
  getBack() {
    history.back();
  }

  // 重置
  public resetForm(): void {
    this.validateForm.reset();
  }

  // 保存

  public getSave(): void {
    // tslint:disable-next-line:forin
    for (const i in this.validateForm.controls) {
      this.validateForm.controls[i].markAsDirty();
      this.validateForm.controls[i].updateValueAndValidity();
      if (this.validateForm.controls[i].errors != null) {
        this.message.error('必填项不能为空');
        return;
      }
    }

    if (this.couponImg.length !== 0) {
      if (this.couponImg[0]['response'] != null) {
        this.validateForm.value.couponImg = this.couponImg[0]['response']['return_data'][0];
      } else {
        this.validateForm.value.couponImg = this.couponImg[0].name;
      }
    } else {
      this.message.error('请上传卡券图片');
      return;
    }

    const couponCarouselImg = [];

    if (this.couponCarouselImg.length !== 0) {
      for (const i of this.couponCarouselImg) {
        if (i['response'] != null) {
          couponCarouselImg.push(i['response']['return_data'][0]);
        } else {
          this.validateForm.value.couponCarouselImg = i.name;
        }
      }
    } else {
      this.message.error('请上传卡券轮播图');
      return;
    }
    this.validateForm.value.couponCarouselImg = couponCarouselImg.join(',');
    this.validateForm.value.couponDesc = this.content;
    if (this.editFlag) {
      this.validateForm.value.id = this.id;
      this.coupon.updateCoupon(this.validateForm.value, data => {
        if (data['return_code'] === '000000') {
          this.getBack();
          this.message.success('修改成功');
        } else {
          this.message.create('error', '修改失败');
        }
      });
    } else {

      this.coupon.insertCoupon(this.validateForm.value, data => {
        if (data['return_code'] === '000000') {
          this.getBack();
          this.message.success('添加成功');
        } else {
          this.message.create('error', '保存失败');
        }
      });
    }
  }

  // 图片查看
  handlePreview = async (file: NzUploadFile) => {
    if (!file.url && !file.preview) {
      // tslint:disable-next-line:no-non-null-assertion
      file.preview = await getBase64(file.originFileObj!);
    }
    this.previewImage = file.url || file.preview;
    this.previewVisible = true;
  }

  public getDetails(id) {
    this.merchant.getMerchantById(id, data => {
      if (data['return_code'] === '000000') {
        if (data['return_data']['merchantLogo'] != null && data['return_data']['merchantLogo'] !== '') {
          const logo = String(data['return_data']['merchantLogo']);
          const logoArray = [];
          logoArray.push(
              {
                uid: 1,
                name: logo,
                status: 'done',
                url: environment.imageUrl + logo
              });
          // this.logoFile = logoArray;
        }
        this.validateForm.patchValue(data['return_data']);
      } else {
        this.message.create('error', data['return_msg']);
      }
    });
  }

  // 富文本内容
  textData(content) {
    this.content = content;
  }
}
