import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import {MerchantService} from '../../../services/merchant.service';
import {IconService} from '../../../services/icon.service';
import {NzMessageService} from 'ng-zorro-antd';
import {ActivatedRoute, Router} from '@angular/router';
import {CommonsService} from '../../../services/commons.service';
import {MerchantStoreService} from '../../../services/merchant-store.service';

@Component({
  selector: 'app-store-list',
  templateUrl: './store-list.component.html',
  styleUrls: ['./store-list.component.scss']
})
export class StoreListComponent implements OnInit {

  searchForm: FormGroup; // 搜索框
  requestData = []; // 列表数据
  total: number; // 页码
  pageNum = 1; // 页码
  pageSize = 10; // 条码
  loading = true;
  id = null;
  name: string;
  constructor(
      private form: FormBuilder,
      private merchantStore: MerchantStoreService,
      private iconService: IconService,
      private message: NzMessageService,
      private router: Router,
      private activatedRoute: ActivatedRoute,
      private common: CommonsService
  ) {
  }

  ngOnInit(): void {
    this.init();

  }

  public init(): void {
    this.activatedRoute.queryParams.subscribe(queryParams => {
      if (queryParams.merchantId != null) {
        this.id = queryParams.merchantId;
        this.name = queryParams.name;
      }
    });
    this.searchForm = this.form.group({
      storeName: [null],
      telephone: [null],
    });
    this.getRequest(true, this.searchForm.value);
  }


  // 查询列表
  public getRequest(reset: boolean = false, whereObject: object) {

    this.loading = false;
    if (reset) {
      this.pageNum = 1;
    }
    whereObject['pageNum'] = this.pageNum;
    whereObject['pageSize'] = this.pageSize;
    if (this.id == null) {
      this.merchantStore.getStoreListByMerchant(whereObject, data => {
        if (data['return_code'] === '000000') {
          this.requestData = data['return_data'].list;
          this.total = data['return_data'].total;
        } else {
          this.message.error(data['return_msg']);
        }
      });
    } else {
      whereObject['merchantId'] = this.id;
      this.merchantStore.getStoreListByCompany(whereObject, data => {
        if (data['return_code'] === '000000') {
          this.requestData = data['return_data'].list;
          this.total = data['return_data'].total;
        } else {
          this.message.error(data['return_msg']);
        }
      });
    }


  }

  // 重置
  public resetForm(): void {
    this.searchForm.reset();
  }

  // 禁用门店
  public getDelete(id): void {
    const message =  '是否删除门店';
    this.common.showConfirm(message, data => {
      if (data) {
        this.merchantStore.deleteMerchantStore(id, dataReturn => {
          if (dataReturn['return_code'] === '000000') {
            this.message.success('操作成功');
            this.getRequest(false , this.searchForm.value);
          } else {
            this.message.warning(dataReturn['return_msg']);
          }
        });
      }
    });
  }

  // 修改
  public getEdit(id: number): void {
    this.router.navigate(['/admin/merchantStore/store-edit'], {
      queryParams: {
        storeId: id
      }
    }).then(r => console.log(r));
  }

  // 查看详情
  public getDetail(id: number): void {
    this.router.navigate(['/admin/merchantStore/store-detail'], {
      queryParams: {
        storeId: id
      }
    }).then(r => console.log(r));
  }

}
