import {NgModule} from '@angular/core';
import {Routes, RouterModule} from '@angular/router';
import {NavigationComponent} from './admin/navigation/navigation.component';
import {InitGuardService} from './services/init-guard.service';

const routes: Routes = [
  {path: '', pathMatch: 'full', redirectTo: 'adminLogin'},
  {
    path: 'adminLogin',
    loadChildren: () => import('./admin/login/login.module').then(m => m.LoginModule)
  },
  {
    path: 'login',
    loadChildren: () => import('./login/login.module').then(m => m.LoginModule)
  },
  {
    path: 'admin', component: NavigationComponent,
    children: [
      {
        path: 'index',
        loadChildren: () => import('./admin/index/index.module').then(m => m.IndexModule),
        canActivate: [InitGuardService]
      },
      {
        path: 'user',
        loadChildren: () => import('./admin/user/user.module').then(m => m.UserModule),
        canActivate: [InitGuardService]
      },
      {
        path: 'merchant',
        loadChildren: () => import('./admin/merchant/merchant.module').then(m => m.MerchantModule),
        canActivate: [InitGuardService]
      },
      {
        path: 'merchantStore',
        loadChildren: () => import('./admin/merchant-store/merchant-store.module').then(m => m.MerchantStoreModule),
        canActivate: [InitGuardService]
      },
      {
        path: 'coupon',
        loadChildren: () => import('./admin/coupon/coupon.module').then(m => m.CouponModule),
        canActivate: [InitGuardService]
      },
      {
        path: 'company',
        loadChildren: () => import('./admin/company/company.module').then(m => m.CompanyModule),
        canActivate: [InitGuardService]
      },
      {
        path: 'system',
        loadChildren: () => import('./admin/system/system.module').then(m => m.SystemModule),
        canActivate: [InitGuardService]
      },
      {
        path: 'cms',
        loadChildren: () => import('./admin/cms/cms.module').then(m => m.CmsModule),
        canActivate: [InitGuardService]
      },
    ],
  },
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule]
})
export class AppRoutingModule {
}
