import { Injectable } from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {CommonsService} from './commons.service';
import {environment} from '../../environments/environment';

@Injectable({
  providedIn: 'root'
})
export class CouponService {
  constructor(
      private http: HttpClient,
      private common: CommonsService
  ) { }

  /**
   * 查询卡券列表
   *
   * @param  paramsObject   对象
   * @param  callBack   回调
   */
  public getCouponList(paramsObject: object, callBack) {
    this.http.get(environment.baseUrl + 'coupon/getCouponList?' + this.common.getWhereCondition(paramsObject)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 新增卡券
   *
   * @param params 上传对象
   * @param  callBack   回调
   * @return data 返回结果
   */
  public insertCoupon(params: object, callBack) {
    this.http.post(environment.baseUrl + 'coupon/insertCoupon', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 修改卡券
   *
   * @param params 上传对象
   * @param  callBack   回调
   * @return data 返回结果
   */
  public updateCoupon(params: object, callBack) {
    this.http.post(environment.baseUrl + 'coupon/updateCoupon', params).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 根据id查询详情
   *
   * @param  merchantId   职位id
   * @param  callBack   回调
   */
  public getMerchantById(merchantId: number, callBack) {
    this.http.get(environment.baseUrl + 'highMerchant/getMerchantById?id=' + merchantId).subscribe(data => {
      callBack(data);
    });
  }


  /**
   * 禁用商户
   *
   * @param id  用户id
   * @param callBack 返回参数
   */
  public disableMerchant(id: number, callBack) {
    this.http.get(environment.baseUrl + 'highMerchant/disableMerchant?id=' + id).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 启用商户
   *
   * @param id  用户id
   * @param callBack 返回参数
   */
  public enableMerchant(id: number, callBack) {
    this.http.get(environment.baseUrl + 'highMerchant/enableMerchant?id=' + id).subscribe(data => {
      callBack(data);
    });
  }


}
